﻿Imports System.Collections.ObjectModel
Imports DlhSoft.Windows.Data

Module Module1

    Sub Main()

        Console.WriteLine("TaskManager Sample")

        ' Prepare the task data collection.
        Dim taskItems As New ObservableCollection(Of TaskItem)
        taskItems.Add(New TaskItem With {.Content = "Task 1", .IndexString = "1"})
        taskItems.Add(New TaskItem With {.Content = "Task 1.1", .Indentation = 1, .Start = DateTime.Today, .Effort = TimeSpan.Parse("08:00:00"), .CompletedEffort = TimeSpan.Parse("04:00:00"), .IndexString = "2"})
        taskItems.Add(New TaskItem With {.Content = "Task 1.2", .Indentation = 1, .IndexString = "3"})
        taskItems.Add(New TaskItem With {.Content = "Task 1.2.1", .Indentation = 2, .Start = DateTime.Today, .Effort = TimeSpan.Parse("08:00:00"), .IndexString = "4"})
        taskItems.Add(New TaskItem With {.Content = "Task 1.2.2", .Indentation = 2, .Start = DateTime.Today, .Effort = TimeSpan.Parse("16:00:00"), .IndexString = "5"})
        taskItems.Add(New TaskItem With {.Content = "Task 2", .IsExpanded = True, .IndexString = "6"})
        taskItems.Add(New TaskItem With {.Content = "Task 2.1", .Indentation = 1, .Start = DateTime.Today, .Effort = TimeSpan.Parse("16:00:00"), .IsCompleted = True, .IndexString = "7"})
        taskItems.Add(New TaskItem With {.Content = "Task 2.2", .Indentation = 1, .Start = DateTime.Today, .Effort = TimeSpan.Parse("08:00:00"), .CompletedEffort = TimeSpan.Parse("06:00:00"), .IndexString = "8"})
        taskItems.Add(New TaskItem With {.Content = "Task 2.3", .Indentation = 1, .IsExpanded = True, .IndexString = "9", .PredecessorsString = "8"})
        taskItems.Add(New TaskItem With {.Content = "Task 2.3.1", .Indentation = 2, .Start = DateTime.Today, .Effort = TimeSpan.Parse("1.16:00:00"), .IndexString = "10", .Cost = 2000})
        taskItems.Add(New TaskItem With {.Content = "Task 2.3.2", .Indentation = 2, .Start = DateTime.Today, .Effort = TimeSpan.Parse("08:00:00"), .IndexString = "11", .PredecessorsString = "10"})
        taskItems.Add(New TaskItem With {.Content = "Task 3", .Start = DateTime.Today, .Effort = TimeSpan.Parse("12:30:00"), .CompletedEffort = TimeSpan.Parse("02:30:00"), .IndexString = "12", .PredecessorsString = "9, 11SS+12"})
        taskItems.Add(New TaskItem With {.Content = "Task 4", .Start = DateTime.Today, .Effort = TimeSpan.Parse("16:00:00"), .AssignmentsString = "Resource 1", .IndexString = "13"})
        taskItems.Add(New TaskItem With {.Content = "Task 5", .Start = DateTime.Today, .Effort = TimeSpan.Parse("20:00:00"), .AssignmentsString = "Resource 1; Resource 2 [50%]", .IndexString = "14"})
        taskItems.Add(New TaskItem With {.Content = "Task 6", .Start = DateTime.Today, .IsMilestone = True, .IndexString = "15", .PredecessorsString = "14+2"})

        ' You can also prepare task data items dynamically.
        For i As Integer = 7 To 64
            taskItems.Add(New TaskItem With {.Content = "Task " & i, .Start = DateTime.Today, .Effort = TimeSpan.Parse("08:00:00")})
        Next

        ' Prepare the assignable resource data collection.
        Dim assignableResourceItems As New ObservableCollection(Of ResourceItem)
        assignableResourceItems.Add(New ResourceItem With {.Content = "Resource 1", .CostPerUsage = 100, .CostPerHour = 10})
        assignableResourceItems.Add(New ResourceItem With {.Content = "Resource 2", .CostPerHour = 20})

        ' You can also prepare assignable resource data items dynamically.
        For i As Integer = 3 To 16
            assignableResourceItems.Add(New ResourceItem With {.Content = "Resource " & i})
        Next

        ' Initialize the assignable ResourceManager object using the prepared assignable resource data items.
        Dim assignableResourceManager As New ResourceManager(assignableResourceItems)
        ' Initialize the TaskManager object using the prepared task data items and assignable resource manager.
        Dim taskManager As New TaskManager(taskItems, assignableResourceManager)

        ' Use the Tasks and other properties of the TaskManager object to access the managed tasks and related information.
        Console.WriteLine("Tasks: Count = {0}) OverallEffort = {1}h, OverallFinish = {2:d}", taskManager.Count, taskManager.OverallEffort.TotalHours, taskManager.OverallFinish)
        For Each task As Task In taskManager.Tasks
            Console.WriteLine("Tasks[{0}]: Start = {1:d}, Effort = {2}h, Finish = {3:d}", task.Index, task.Start, task.Effort.TotalHours, task.Finish)
        Next

        ' Dispose the TaskManager and ResourceManager objects when they are no longer needed.
        taskManager.Dispose()
        assignableResourceManager.Dispose()

    End Sub

End Module
